aboutsummaryrefslogtreecommitdiff
path: root/sys/dev
diff options
context:
space:
mode:
authorAmancio Hasty <ahasty@FreeBSD.org>1997-12-31 05:45:56 +0000
committerAmancio Hasty <ahasty@FreeBSD.org>1997-12-31 05:45:56 +0000
commit3c8163d8bf7787f46136e43492b602e38459e333 (patch)
tree87dda254abf1ee8378bdcd7fddd18334ba81b9ea /sys/dev
parent32865140bc5d65bebb70c5be786c37dd72123318 (diff)
Notes
Diffstat (limited to 'sys/dev')
-rw-r--r--sys/dev/bktr/bktr_core.c24
1 files changed, 20 insertions, 4 deletions
diff --git a/sys/dev/bktr/bktr_core.c b/sys/dev/bktr/bktr_core.c
index 74099652570c..38ae10a5d31c 100644
--- a/sys/dev/bktr/bktr_core.c
+++ b/sys/dev/bktr/bktr_core.c
@@ -1,4 +1,4 @@
/* BT848 1.20 Driver for Brooktree's Bt848 based cards.
The Brooktree BT848 Driver driver is based upon Mark Tinguely and
Jim Lowe's driver for the Matrox Meteor PCI card . The
Philips SAA 7116 and SAA 7196 are very different chipsets than
@@ -199,6 +199,8 @@
Fixes for packed 24bpp - FIFO alignment
1.23 11/17/97 Amancio <hasty@star-gate.com>
Added yuv support mpeg encoding
+1.24 12/27/97 Jonathan Hanna <pangolin@rogers.wave.ca>
+ Patch to support Philips FR1236MK2 tuner
*/
@@ -530,6 +532,10 @@ static struct {
#define PHILIPS_NTSC_WADDR 0xc6
#define PHILIPS_NTSC_RADDR 0xc7
+/* PLL on a the Philips FR1236MK2 tuner */
+#define PHILIPS_FR1236_NTSC_WADDR 0xc2
+#define PHILIPS_FR1236_NTSC_RADDR 0xc3
+
/* guaranteed address for any TSA5522/3 (PLL on all(?) tuners) */
#define TSA552x_WADDR 0xc2
#define TSA552x_RADDR 0xc3
@@ -3714,6 +3720,8 @@ const struct CARDTYPE cards[] = {
#define PHILIPS_SECAM 6
#define TEMIC_PALI 7
#define PHILIPS_PALI 8
+#define PHILIPS_FR1236_NTSC 9
+
/* XXX FIXME: this list is incomplete */
/* input types */
@@ -3805,9 +3813,17 @@ const struct TUNER tuners[] = {
{ "Philips PAL I", /* the 'name' */
TTYPE_PAL, /* input type */
0x00, /* PLL write address */
- TSA552x_SCONTROL, /* control byte for PLL */
- { 0x00, 0x00 }, /* band-switch crosspoints */
- { 0xa0, 0x90, 0x30 } }, /* the band-switch values */
+ TSA552x_SCONTROL, /* control byte for PLL */
+ { 0x00, 0x00 }, /* band-switch crosspoints */
+ { 0xa0, 0x90, 0x30 } }, /* the band-switch values */
+
+ /* PHILIPS_FR1236_NTSC */
+ { "Philips FR1236 NTSC FM", /* the 'name' */
+ TTYPE_NTSC, /* input type */
+ PHILIPS_FR1236_NTSC_WADDR, /* PLL write address */
+ TSA552x_SCONTROL, /* control byte for PLL */
+ { 0x00, 0x00 }, /* band-switch crosspoints */
+ { 0xa0, 0x90, 0x30 } }, /* the band-switch values */
};
@@ -1,4 +1,4 @@
-/* BT848 1.20 Driver for Brooktree's Bt848 based cards.
+/* BT848 1.24 Driver for Brooktree's Bt848 based cards.
The Brooktree BT848 Driver driver is based upon Mark Tinguely and
Jim Lowe's driver for the Matrox Meteor PCI card . The